@@ -252,3 +252,13 @@ def __save_file__(path, data):
 	file = open(path, "w+") 
 	file.write(data)
 	file.close()
+
+# save & load bytes.
+def __load_bytes__(path):
+	data = None
+	with open(path, "rb") as file:
+		data = file.read()
+	return data
+def __save_bytes__(path, data):
+	with open(path, "wb") as file:
+		file.write(data)
\ No newline at end of file
